
# About

A package pipeline for Sleep Events Analysis of EEG data.

seapipe is a Python pipeline for **S**leep **E**vents **A**nalysis. 
The package reads EEG recordings with the purpose of detecting and 
analysing sleep neurophysiology, such as sleep architecture statistics, 
sleep spindles, slow oscillations, phase amplitude coupling, 
and power spectral analyses.

It pulls functions from a range of other open source packages, including: 
Wonambi, YASA, MNE, specparam (fooof) and Tensorpac

It offers a simple and intuitive, yet fully customisable API. 
The major advantage of seapipe is that it can be deployed on full, 
diverse datasets that might require flexibility in certain parameters 
(e.g. electrode names, polarity of recordings, individualised frequency bands etc). 
The only requirement is that the data should be structured in BIDS.

For more information, check out the documentation at: https://seapipe.readthedocs.io/en/latest/index.html


![](img/Fig1.png)

